[openssl-commits] Build failed in Jenkins: master_noec #437

2018-03-16 Thread osslsanity
See 


Changes:

[Matthias.St.Pierre] RAND_DRBG: add a function for setting the default DRBG 
type and flags

--
[...truncated 524.26 KB...]
rm -f test/tls13encryptiontest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/tls13encryptiontest test/tls13encryptiontest.o \
 libssl.a test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -I. -Iinclude -Iapps -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  
-MMD -MF test/uitest.d.tmp -MT test/uitest.o -c -o test/uitest.o test/uitest.c
rm -f test/uitest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/uitest test/uitest.o \
 apps/libapps.a -lssl test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/v3ext.d.tmp -MT test/v3ext.o -c -o test/v3ext.o test/v3ext.c
rm -f test/v3ext
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/v3ext test/v3ext.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/v3nametest.d.tmp -MT test/v3nametest.o -c -o test/v3nametest.o 
test/v3nametest.c
rm -f test/v3nametest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/v3nametest test/v3nametest.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/verify_extra_test.d.tmp -MT test/verify_extra_test.o -c -o 
test/verify_extra_test.o test/verify_extra_test.c
rm -f test/verify_extra_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/verify_extra_test test/verify_extra_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/wpackettest.d.tmp -MT test/wpackettest.o -c -o test/wpackettest.o 
test/wpackettest.c
rm -f test/wpackettest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/wpackettest test/wpackettest.o \
 libssl.a test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509_check_cert_pkey_test.d.tmp -MT test/x509_check_cert_pkey_test.o -c -o 
test/x509_check_cert_pkey_test.o test/x509_check_cert_pkey_test.c
rm -f test/x509_check_cert_pkey_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_check_cert_pkey_test 
test/x509_check_cert_pkey_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509_dup_cert_test.d.tmp -MT test/x509_dup_cert_test.o -c -o 
test/x509_dup_cert_test.o test/x509_dup_cert_test.c
rm -f test/x509_dup_cert_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_dup_cert_test test/x509_dup_cert_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -I. -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD 
-MF test/x509_internal_test.d.tmp -MT test/x509_internal_test.o -c -o 
test/x509_internal_test.o test/x509_internal_test.c
rm -f test/x509_internal_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_internal_test test/x509_internal_test.o \
 test/libtestutil.a libcrypto.a -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509_time_test.d.tmp -MT test/x509_time_test.o -c -o test/x509_time_test.o 
test/x509_time_test.c
rm -f test/x509_time_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_time_test test/x509_time_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509aux.d.tmp -MT test/x509aux.o -c -o test/x509aux.o test/x509aux.c
rm -f test/x509aux
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509aux test/x509aux.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
/usr/bin/perl "-I." -Mconfigdata "util/dofile.pl" \
"-oMakefile" apps/CA.pl.in > "apps/CA.pl"
chmod a+x apps/CA.pl
/usr/bin/perl "-I." -Mconfigdata "util/dofile.pl" \
"-oMakefile" apps/tsget.in > "apps/tsget"
chmod a+x apps/tsget
/usr/bin/perl "-I." -Mconfigdata "util/dofile.pl" \
"-oMakefile" tools/c_rehash.in > "tools/c_rehash"
chmod a+x tools/c_rehash
/usr/bin/perl "-I." -Mconfigdata "util/dofile.pl" \
"-oMakefile" util/shlib_wrap.sh.in > "util/shlib_wrap.sh"
chmod a+x 

[openssl-commits] Build completed: openssl master.16494

2018-03-16 Thread AppVeyor


Build openssl master.16494 completed



Commit 81529d0999 by Andy Polyakov on 3/16/2018 6:44 PM:

NOTES.WIN: address feedback, re-wording, typos... [to be squashed]


Configure your notification preferences

_
openssl-commits mailing list
To unsubscribe: https://mta.openssl.org/mailman/listinfo/openssl-commits


[openssl-commits] Build failed: openssl master.16493

2018-03-16 Thread AppVeyor



Build openssl master.16493 failed


Commit 0216d6ee82 by Matt Caswell on 3/16/2018 6:41 PM:

fixup! Add a test for 0RTT replay protection


Configure your notification preferences

_
openssl-commits mailing list
To unsubscribe: https://mta.openssl.org/mailman/listinfo/openssl-commits


[openssl-commits] [openssl] master update

2018-03-16 Thread matthias . st . pierre
The branch master has been updated
   via  31393fd9067a1444fe4b73bfac51ab44d8d344e2 (commit)
  from  80f2787717c2181438d4dc2da701fe784fd6286e (commit)


- Log -
commit 31393fd9067a1444fe4b73bfac51ab44d8d344e2
Author: Dr. Matthias St. Pierre 
Date:   Thu Mar 15 19:48:43 2018 +0100

RAND_DRBG: add a function for setting the default DRBG type and flags

This commit adds a new api RAND_DRBG_set_defaults() which sets the
default type and flags for new DRBG instances. See also #5576.

Reviewed-by: Richard Levitte 
(Merged from https://github.com/openssl/openssl/pull/5632)

---

Summary of changes:
 crypto/err/openssl.txt  |  2 ++
 crypto/rand/drbg_ctr.c  |  2 +-
 crypto/rand/drbg_lib.c  | 55 -
 crypto/rand/rand_err.c  |  4 
 crypto/rand/rand_lcl.h  |  2 +-
 include/openssl/rand_drbg.h | 11 ++---
 include/openssl/randerr.h   |  2 ++
 ssl/ssl_lib.c   |  2 +-
 util/libcrypto.num  |  1 +
 9 files changed, 69 insertions(+), 12 deletions(-)

diff --git a/crypto/err/openssl.txt b/crypto/err/openssl.txt
index 176a82b..728013b 100644
--- a/crypto/err/openssl.txt
+++ b/crypto/err/openssl.txt
@@ -916,6 +916,7 @@ RAND_F_RAND_DRBG_NEW:109:RAND_DRBG_new
 RAND_F_RAND_DRBG_RESEED:110:RAND_DRBG_reseed
 RAND_F_RAND_DRBG_RESTART:102:rand_drbg_restart
 RAND_F_RAND_DRBG_SET:104:RAND_DRBG_set
+RAND_F_RAND_DRBG_SET_DEFAULTS:121:RAND_DRBG_set_defaults
 RAND_F_RAND_DRBG_UNINSTANTIATE:118:RAND_DRBG_uninstantiate
 RAND_F_RAND_LOAD_FILE:111:RAND_load_file
 RAND_F_RAND_POOL_ADD:103:rand_pool_add
@@ -2314,6 +2315,7 @@ RAND_R_RANDOM_POOL_OVERFLOW:125:random pool overflow
 RAND_R_REQUEST_TOO_LARGE_FOR_DRBG:117:request too large for drbg
 RAND_R_RESEED_ERROR:118:reseed error
 RAND_R_SELFTEST_FAILURE:119:selftest failure
+RAND_R_UNSUPPORTED_DRBG_FLAGS:132:unsupported drbg flags
 RAND_R_UNSUPPORTED_DRBG_TYPE:120:unsupported drbg type
 RSA_R_ALGORITHM_MISMATCH:100:algorithm mismatch
 RSA_R_BAD_E_VALUE:101:bad e value
diff --git a/crypto/rand/drbg_ctr.c b/crypto/rand/drbg_ctr.c
index 84425dc..ac4af33 100644
--- a/crypto/rand/drbg_ctr.c
+++ b/crypto/rand/drbg_ctr.c
@@ -317,7 +317,7 @@ int drbg_ctr_init(RAND_DRBG *drbg)
 RAND_DRBG_CTR *ctr = >data.ctr;
 size_t keylen;
 
-switch (drbg->nid) {
+switch (drbg->type) {
 default:
 /* This can't happen, but silence the compiler warning. */
 return 0;
--
[...truncated 524.23 KB...]
rm -f test/tls13encryptiontest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/tls13encryptiontest test/tls13encryptiontest.o \
 libssl.a test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -I. -Iinclude -Iapps -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  
-MMD -MF test/uitest.d.tmp -MT test/uitest.o -c -o test/uitest.o test/uitest.c
rm -f test/uitest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/uitest test/uitest.o \
 apps/libapps.a -lssl test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/v3ext.d.tmp -MT test/v3ext.o -c -o test/v3ext.o test/v3ext.c
rm -f test/v3ext
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/v3ext test/v3ext.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/v3nametest.d.tmp -MT test/v3nametest.o -c -o test/v3nametest.o 
test/v3nametest.c
rm -f test/v3nametest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/v3nametest test/v3nametest.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/verify_extra_test.d.tmp -MT test/verify_extra_test.o -c -o 
test/verify_extra_test.o test/verify_extra_test.c
rm -f test/verify_extra_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/verify_extra_test test/verify_extra_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/wpackettest.d.tmp -MT test/wpackettest.o -c -o test/wpackettest.o 
test/wpackettest.c
rm -f test/wpackettest
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/wpackettest test/wpackettest.o \
 libssl.a test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509_check_cert_pkey_test.d.tmp -MT test/x509_check_cert_pkey_test.o -c -o 
test/x509_check_cert_pkey_test.o test/x509_check_cert_pkey_test.c
rm -f test/x509_check_cert_pkey_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_check_cert_pkey_test 
test/x509_check_cert_pkey_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509_dup_cert_test.d.tmp -MT test/x509_dup_cert_test.o -c -o 
test/x509_dup_cert_test.o test/x509_dup_cert_test.c
rm -f test/x509_dup_cert_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_dup_cert_test test/x509_dup_cert_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -I. -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD 
-MF test/x509_internal_test.d.tmp -MT test/x509_internal_test.o -c -o 
test/x509_internal_test.o test/x509_internal_test.c
rm -f test/x509_internal_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_internal_test test/x509_internal_test.o \
 test/libtestutil.a libcrypto.a -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509_time_test.d.tmp -MT test/x509_time_test.o -c -o test/x509_time_test.o 
test/x509_time_test.c
rm -f test/x509_time_test
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509_time_test test/x509_time_test.o \
 test/libtestutil.a -lcrypto -ldl -pthread 
gcc  -Iinclude -pthread -m64  -Wa,--noexecstack -Wall -O3 -DNDEBUG  -MMD -MF 
test/x509aux.d.tmp -MT test/x509aux.o -c -o test/x509aux.o test/x509aux.c
rm -f test/x509aux
${LDCMD:-gcc} -pthread -m64  -Wa,--noexecstack -Wall -O3 -L.   \
-o test/x509aux test/x509aux.o \
 

[openssl-commits] Build failed: openssl master.16482

2018-03-16 Thread AppVeyor



Build openssl master.16482 failed


Commit 2b2dfbfff3 by Matt Caswell on 3/16/2018 11:29 AM:

fixup! Document the replay protection capabilities


Configure your notification preferences

_
openssl-commits mailing list
To unsubscribe: https://mta.openssl.org/mailman/listinfo/openssl-commits


[openssl-commits] Still FAILED build of OpenSSL branch master with options -d --strict-warnings no-psk

2018-03-16 Thread OpenSSL run-checker
Platform and configuration command:

$ uname -a
Linux run 4.4.0-116-generic #140-Ubuntu SMP Mon Feb 12 21:23:04 UTC 2018 x86_64 
x86_64 x86_64 GNU/Linux
$ CC=clang ../openssl/config -d --strict-warnings no-psk

Commit log since last time:

ca1ed29 VMS: add alias macros to avoid 31 character symbol name limit warning
ad3350a Windows makefile: don't use different looking variants of same cmd
6decf94 Publish the RAND_DRBG API
f297e4e Add code to run test, get malloc counts
23be743 util/postprocess-makedepend.pl: make an effort to collect dependencies
27c4490 util/postprocess-makedepend.pl: For VC, don't include system headers
bbb9413 Streamline dependency generation
7731e61 Fix no-chacha and no-poly1305
0198512 Fix a memory leak in the ca application
5af8844 Allow multiple entries without a Subject even if unique_subject == yes
2cedf79 Report a readable error on a duplicate cert in ca app
c845ff0 Revert "Don't allow an empty Subject when creating a Certificate"
62e394d Revert "Don't crash on a missing Subject in index.txt"
f929439 Rename EVP_PKEY_new_private_key()/EVP_PKEY_new_public_key()
e8f9f08 Add functions for setting the new EVP_PKEY_ASN1_METHOD functions
0bcc8ec Make sure all errors go on the stack in the EVP_PKEY_new*() functions
82dd65a Expand the 25519/448 overview man pages
0f987bd Add some test vectors for testing raw 448/25519 keys
4665244 Add PrivateKeyRaw and PublicKeyRaw support to evp_test
d45a97f Add documentation for the newly added EVP_PKEY_new*() functions
9442c8d Update the tests to use the new EVP_PKEY_new_private_key() function
b3831fb Add the function EVP_PKEY_new_CMAC_key()
2621c84 Add support for setting raw private Poly1305 keys
5539c5d Add support for setting raw private SIPHASH keys
e32b52a Add support for setting raw private HMAC keys
cc8b15c Add support for setting raw private/public 25519/448 keys
a08802c Add functions to create an EVP_PKEY from raw private/public key data
9e381e8 Configure: allow to enable afalgeng if target does not start with Linux
16ff134 Only update the server session cache when the session is ready
5cd4225 Missings OIDs for XTS added.

Build log ended with (last 100 lines):

clang  -I. -Icrypto/include -Iinclude -I../openssl -I../openssl/crypto/include 
-I../openssl/include -fPIC -pthread -m64 -Qunused-arguments -DDEBUG_UNUSED 
-DPEDANTIC -pedantic -Wno-long-long -Wall -Wextra -Wno-unused-parameter 
-Wno-missing-field-initializers -Wswitch -Wsign-compare -Wmissing-prototypes 
-Wshadow -Wformat -Wtype-limits -Wundef -Werror  -Wswitch-default 
-Wno-parentheses-equality -Wno-language-extension-token -Wno-extended-offsetof 
-Wconditional-uninitialized -Wincompatible-pointer-types-discards-qualifiers 
-Wmissing-variable-declarations -Wno-unknown-warning-option -Wall -O0 -g 
-DOPENSSL_USE_NODELETE -DL_ENDIAN -DDSO_DLFCN -DHAVE_DLFCN_H -DOPENSSL_PIC 
-DOPENSSL_CPUID_OBJ -DOPENSSL_IA32_SSE2 -DOPENSSL_BN_ASM_MONT 
-DOPENSSL_BN_ASM_MONT5 -DOPENSSL_BN_ASM_GF2m -DSHA1_ASM -DSHA256_ASM 
-DSHA512_ASM -DRC4_ASM -DMD5_ASM -DAES_ASM -DVPAES_ASM -DBSAES_ASM -DGHASH_ASM 
-DECP_NISTZ256_ASM -DX25519_ASM -DPADLOCK_ASM -DPOLY1305_ASM 
-DOPENSSLDIR="\"/usr/local/ssl\"" -DENGINESDIR="\"/usr
 /local/lib/engines-1.1\""   -MMD -MF crypto/x509v3/v3_crld.d.tmp -MT 
crypto/x509v3/v3_crld.o -c -o crypto/x509v3/v3_crld.o 
../openssl/crypto/x509v3/v3_crld.c
clang  -I. -Icrypto/include -Iinclude -I../openssl -I../openssl/crypto/include 
-I../openssl/include -fPIC -pthread -m64 -Qunused-arguments -DDEBUG_UNUSED 
-DPEDANTIC -pedantic -Wno-long-long -Wall -Wextra -Wno-unused-parameter 
-Wno-missing-field-initializers -Wswitch -Wsign-compare -Wmissing-prototypes 
-Wshadow -Wformat -Wtype-limits -Wundef -Werror  -Wswitch-default 
-Wno-parentheses-equality -Wno-language-extension-token -Wno-extended-offsetof 
-Wconditional-uninitialized -Wincompatible-pointer-types-discards-qualifiers 
-Wmissing-variable-declarations -Wno-unknown-warning-option -Wall -O0 -g 
-DOPENSSL_USE_NODELETE -DL_ENDIAN -DDSO_DLFCN -DHAVE_DLFCN_H -DOPENSSL_PIC 
-DOPENSSL_CPUID_OBJ -DOPENSSL_IA32_SSE2 -DOPENSSL_BN_ASM_MONT 
-DOPENSSL_BN_ASM_MONT5 -DOPENSSL_BN_ASM_GF2m -DSHA1_ASM -DSHA256_ASM 
-DSHA512_ASM -DRC4_ASM -DMD5_ASM -DAES_ASM -DVPAES_ASM -DBSAES_ASM -DGHASH_ASM 
-DECP_NISTZ256_ASM -DX25519_ASM -DPADLOCK_ASM -DPOLY1305_ASM 
-DOPENSSLDIR="\"/usr/local/ssl\"" -DENGINESDIR="\"/usr
 /local/lib/engines-1.1\""   -MMD -MF crypto/x509v3/v3_enum.d.tmp -MT 
crypto/x509v3/v3_enum.o -c -o crypto/x509v3/v3_enum.o 
../openssl/crypto/x509v3/v3_enum.c
clang  -I. -Icrypto/include -Iinclude -I../openssl -I../openssl/crypto/include 
-I../openssl/include -fPIC -pthread -m64 -Qunused-arguments -DDEBUG_UNUSED 
-DPEDANTIC -pedantic -Wno-long-long -Wall -Wextra -Wno-unused-parameter 
-Wno-missing-field-initializers -Wswitch -Wsign-compare -Wmissing-prototypes 
-Wshadow -Wformat -Wtype-limits -Wundef -Werror  -Wswitch-default 
-Wno-parentheses-equality -Wno-language-extension-token -Wno-extended-offsetof 
-Wconditional-uninitialized 

[openssl-commits] Still FAILED build of OpenSSL branch master with options -d --strict-warnings no-posix-io

2018-03-16 Thread OpenSSL run-checker
Platform and configuration command:

$ uname -a
Linux run 4.4.0-116-generic #140-Ubuntu SMP Mon Feb 12 21:23:04 UTC 2018 x86_64 
x86_64 x86_64 GNU/Linux
$ CC=clang ../openssl/config -d --strict-warnings no-posix-io

Commit log since last time:

ca1ed29 VMS: add alias macros to avoid 31 character symbol name limit warning
ad3350a Windows makefile: don't use different looking variants of same cmd
6decf94 Publish the RAND_DRBG API
f297e4e Add code to run test, get malloc counts
23be743 util/postprocess-makedepend.pl: make an effort to collect dependencies
27c4490 util/postprocess-makedepend.pl: For VC, don't include system headers
bbb9413 Streamline dependency generation
7731e61 Fix no-chacha and no-poly1305
0198512 Fix a memory leak in the ca application
5af8844 Allow multiple entries without a Subject even if unique_subject == yes
2cedf79 Report a readable error on a duplicate cert in ca app
c845ff0 Revert "Don't allow an empty Subject when creating a Certificate"
62e394d Revert "Don't crash on a missing Subject in index.txt"
f929439 Rename EVP_PKEY_new_private_key()/EVP_PKEY_new_public_key()
e8f9f08 Add functions for setting the new EVP_PKEY_ASN1_METHOD functions
0bcc8ec Make sure all errors go on the stack in the EVP_PKEY_new*() functions
82dd65a Expand the 25519/448 overview man pages
0f987bd Add some test vectors for testing raw 448/25519 keys
4665244 Add PrivateKeyRaw and PublicKeyRaw support to evp_test
d45a97f Add documentation for the newly added EVP_PKEY_new*() functions
9442c8d Update the tests to use the new EVP_PKEY_new_private_key() function
b3831fb Add the function EVP_PKEY_new_CMAC_key()
2621c84 Add support for setting raw private Poly1305 keys
5539c5d Add support for setting raw private SIPHASH keys
e32b52a Add support for setting raw private HMAC keys
cc8b15c Add support for setting raw private/public 25519/448 keys
a08802c Add functions to create an EVP_PKEY from raw private/public key data
9e381e8 Configure: allow to enable afalgeng if target does not start with Linux
16ff134 Only update the server session cache when the session is ready
5cd4225 Missings OIDs for XTS added.

Build log ended with (last 100 lines):

chmod a+x apps/tsget
/usr/bin/perl "-I." -Mconfigdata "../openssl/util/dofile.pl" \
"-oMakefile" ../openssl/tools/c_rehash.in > "tools/c_rehash"
/usr/bin/perl "-I." -Mconfigdata "../openssl/util/dofile.pl" \
"-oMakefile" ../openssl/util/shlib_wrap.sh.in > "util/shlib_wrap.sh"
ar r apps/libapps.a apps/app_rand.o apps/apps.o apps/bf_prefix.o apps/opt.o 
apps/s_cb.o apps/s_socket.o
ar: creating apps/libapps.a
ranlib apps/libapps.a || echo Never mind.
clang -fPIC -pthread -m64 -Qunused-arguments -DDEBUG_UNUSED -DPEDANTIC 
-pedantic -Wno-long-long -Wall -Wextra -Wno-unused-parameter 
-Wno-missing-field-initializers -Wswitch -Wsign-compare -Wmissing-prototypes 
-Wshadow -Wformat -Wtype-limits -Wundef -Werror  -Wswitch-default 
-Wno-parentheses-equality -Wno-language-extension-token -Wno-extended-offsetof 
-Wconditional-uninitialized -Wincompatible-pointer-types-discards-qualifiers 
-Wmissing-variable-declarations -Wno-unknown-warning-option -Wall -O0 -g 
-DOPENSSL_USE_NODELETE -DL_ENDIAN -DDSO_DLFCN -DHAVE_DLFCN_H -DOPENSSL_PIC 
-DOPENSSL_CPUID_OBJ -DOPENSSL_IA32_SSE2 -DOPENSSL_BN_ASM_MONT 
-DOPENSSL_BN_ASM_MONT5 -DOPENSSL_BN_ASM_GF2m -DSHA1_ASM -DSHA256_ASM 
-DSHA512_ASM -DRC4_ASM -DMD5_ASM -DAES_ASM -DVPAES_ASM -DBSAES_ASM -DGHASH_ASM 
-DECP_NISTZ256_ASM -DX25519_ASM -DPADLOCK_ASM -DPOLY1305_ASM 
-DOPENSSLDIR="\"/usr/local/ssl\"" -DENGINESDIR="\"/usr/local/lib/engines-1.1\"" 
  -c -o crypto/aes/aes-x86_64.o crypto/aes/aes-x86_64.s
clang -fPIC -pthread -m64 -Qunused-arguments -DDEBUG_UNUSED -DPEDANTIC 
-pedantic -Wno-long-long -Wall -Wextra -Wno-unused-parameter 
-Wno-missing-field-initializers -Wswitch -Wsign-compare -Wmissing-prototypes 
-Wshadow -Wformat -Wtype-limits -Wundef -Werror  -Wswitch-default 
-Wno-parentheses-equality -Wno-language-extension-token -Wno-extended-offsetof 
-Wconditional-uninitialized -Wincompatible-pointer-types-discards-qualifiers 
-Wmissing-variable-declarations -Wno-unknown-warning-option -Wall -O0 -g 
-DOPENSSL_USE_NODELETE -DL_ENDIAN -DDSO_DLFCN -DHAVE_DLFCN_H -DOPENSSL_PIC 
-DOPENSSL_CPUID_OBJ -DOPENSSL_IA32_SSE2 -DOPENSSL_BN_ASM_MONT 
-DOPENSSL_BN_ASM_MONT5 -DOPENSSL_BN_ASM_GF2m -DSHA1_ASM -DSHA256_ASM 
-DSHA512_ASM -DRC4_ASM -DMD5_ASM -DAES_ASM -DVPAES_ASM -DBSAES_ASM -DGHASH_ASM 
-DECP_NISTZ256_ASM -DX25519_ASM -DPADLOCK_ASM -DPOLY1305_ASM 
-DOPENSSLDIR="\"/usr/local/ssl\"" -DENGINESDIR="\"/usr/local/lib/engines-1.1\"" 
  -c -o crypto/aes/aesni-mb-x86_64.o crypto/aes/aesni-mb-x86_64.s
chmod a+x tools/c_rehash
clang -fPIC -pthread -m64 -Qunused-arguments -DDEBUG_UNUSED -DPEDANTIC 
-pedantic -Wno-long-long -Wall -Wextra -Wno-unused-parameter 
-Wno-missing-field-initializers -Wswitch -Wsign-compare -Wmissing-prototypes 
-Wshadow -Wformat -Wtype-limits -Wundef -Werror  -Wswitch-default 
-Wno-parentheses-equality -Wno-language-extension-token 

[openssl-commits] SUCCESSFUL build of OpenSSL branch master with options -d --strict-warnings no-poly1305

2018-03-16 Thread OpenSSL run-checker
Platform and configuration command:

$ uname -a
Linux run 4.4.0-116-generic #140-Ubuntu SMP Mon Feb 12 21:23:04 UTC 2018 x86_64 
x86_64 x86_64 GNU/Linux
$ CC=clang ../openssl/config -d --strict-warnings no-poly1305

Commit log since last time:

ca1ed29 VMS: add alias macros to avoid 31 character symbol name limit warning
ad3350a Windows makefile: don't use different looking variants of same cmd
6decf94 Publish the RAND_DRBG API
f297e4e Add code to run test, get malloc counts
23be743 util/postprocess-makedepend.pl: make an effort to collect dependencies
27c4490 util/postprocess-makedepend.pl: For VC, don't include system headers
bbb9413 Streamline dependency generation
7731e61 Fix no-chacha and no-poly1305
0198512 Fix a memory leak in the ca application
5af8844 Allow multiple entries without a Subject even if unique_subject == yes
2cedf79 Report a readable error on a duplicate cert in ca app
c845ff0 Revert "Don't allow an empty Subject when creating a Certificate"
62e394d Revert "Don't crash on a missing Subject in index.txt"
f929439 Rename EVP_PKEY_new_private_key()/EVP_PKEY_new_public_key()
e8f9f08 Add functions for setting the new EVP_PKEY_ASN1_METHOD functions
0bcc8ec Make sure all errors go on the stack in the EVP_PKEY_new*() functions
82dd65a Expand the 25519/448 overview man pages
0f987bd Add some test vectors for testing raw 448/25519 keys
4665244 Add PrivateKeyRaw and PublicKeyRaw support to evp_test
d45a97f Add documentation for the newly added EVP_PKEY_new*() functions
9442c8d Update the tests to use the new EVP_PKEY_new_private_key() function
b3831fb Add the function EVP_PKEY_new_CMAC_key()
2621c84 Add support for setting raw private Poly1305 keys
5539c5d Add support for setting raw private SIPHASH keys
e32b52a Add support for setting raw private HMAC keys
cc8b15c Add support for setting raw private/public 25519/448 keys
a08802c Add functions to create an EVP_PKEY from raw private/public key data
9e381e8 Configure: allow to enable afalgeng if target does not start with Linux
16ff134 Only update the server session cache when the session is ready
5cd4225 Missings OIDs for XTS added.
_
openssl-commits mailing list
To unsubscribe: https://mta.openssl.org/mailman/listinfo/openssl-commits


[openssl-commits] [openssl] master update

2018-03-16 Thread Richard Levitte
The branch master has been updated
   via  80f2787717c2181438d4dc2da701fe784fd6286e (commit)
   via  f58461791d3dbf94fbc5254a27fc45eff7f34a6c (commit)
   via  ac6ae8a9fe25df159d04b7ea7c121c63fc05aae9 (commit)
  from  8ed5f094584203855a2bc8cf35c02267e6f64780 (commit)


- Log -
commit 80f2787717c2181438d4dc2da701fe784fd6286e
Author: Richard Levitte 
Date:   Fri Mar 16 10:47:36 2018 +0100

INSTALL: Add a note about backward compatibility and "make variables"

Reviewed-by: Andy Polyakov 
(Merged from https://github.com/openssl/openssl/pull/5641)

commit f58461791d3dbf94fbc5254a27fc45eff7f34a6c
Author: Richard Levitte 
Date:   Fri Mar 16 08:59:03 2018 +0100

Configure: maintain compability with pre-"make variables" Configure

There were a few environment variables that we supported in earlier
Configure versions which got transfered to the %user table.  This
change makes sure that we still support them, by simply pre-populating
the corresponding %user entries with those environment values.

Reviewed-by: Andy Polyakov 
(Merged from https://github.com/openssl/openssl/pull/5641)

commit ac6ae8a9fe25df159d04b7ea7c121c63fc05aae9
Author: Richard Levitte 
Date:   Fri Mar 16 08:24:50 2018 +0100

Configure: Don't fail if there were "make variables" set in env

The original intent was that if someone had a "make variable" set in
any kind of way, be it as an environment variable or as an argument to
Configure, we wouldn't allow compiler or linker flags as arguments as
well.  That made both of these configurations equivalently impossible:

./Configure target CFLAGS=-foo -lextra

 CFLAGS=-foo ./Configure target -lextra

While this makes things look nice and consistent, real world use makes
this hard, as many projects where OpenSSL is a component also set
these variables for other components that use GNU autotools.

Therefore, we need to adapt our Configure accordingly.  By
consequence, the two Configure lines above will not be equivalent any
more:

./Configure target CFLAGS=-foo -lextra

This command line will still fail, because the "make variable" was
given as a command line argument.  This cannot be a mistake and is
therefore not allowed.

 CFLAGS=-foo ./Configure target -lextra

This command line will work, but because there is a linker flag as
a command line argument, the environment (i.e. CFLAGS) is ignored.
That isn't quite consistent with the previous command, but is the old
Configure behavior, before the support for "make variables" was added,
and is therefore the backward compatible behavior.

Fixes google/oss-fuzz#1244

Reviewed-by: Andy Polyakov 
(Merged from https://github.com/openssl/openssl/pull/5641)

---

Summary of changes:
 Configure | 68 +++
 INSTALL   | 20 ++-
 2 files changed, 61 insertions(+), 27 deletions(-)

diff --git a/Configure b/Configure
index ca90a75..8efd8bf 100755
--- a/Configure
+++ b/Configure
@@ -523,28 +523,30 @@ my $list_separator_re =
 { VMS   => qr/(? qr/(? {$^O} // qr/(? undef,
+AR  => env('AR'),
 ARFLAGS => [],
 AS  => undef,
 ASFLAGS => [],
-CC  => undef,
+CC  => env('CC'),
 CFLAGS  => [],
-CXX => undef,
+CXX => env('CXX'),
 CXXFLAGS=> [],
 CPP => undef,
 CPPFLAGS=> [],  # -D, -I, -Wp,
 CPPDEFINES  => [],  # Alternative for -D
 CPPINCLUDES => [],  # Alternative for -I
-CROSS_COMPILE => undef,
-HASHBANGPERL=> undef,
+CROSS_COMPILE => env('CROSS_COMPILE'),
+HASHBANGPERL=> env('HASHBANGPERL') || env('PERL'),
 LD  => undef,
 LDFLAGS => [],  # -L, -Wl,
 LDLIBS  => [],  # -l
 MT  => undef,
 MTFLAGS => [],
-RANLIB  => undef,
-RC  => undef,
+RANLIB  => env('RANLIB'),
+RC  => env('RC') || env('WINDRES'),
 RCFLAGS => [],
 RM  => undef,
);
@@ -602,6 +604,7 @@ $config{options}="";
 $config{build_type} = "release";
 my $target="";
 
+my %cmdvars = ();   # Stores FOO='blah' type arguments
 my %unsupported_options = ();
 my %deprecated_options = ();
 # If you change this, update apps/version.c
@@ -614,7 +617,7 @@ while (@argvcopy)
# Support env variable assignments among the options
if (m|^(\w+)=(.+)?$|)
{
-   $config{perlenv}->{$1} = $2;
+   $cmdvars{$1} = $2;
# Every time a variable is given as a 

[openssl-commits] [openssl] master update

2018-03-16 Thread Richard Levitte
The branch master has been updated
   via  8ed5f094584203855a2bc8cf35c02267e6f64780 (commit)
   via  433e857214731b45565668931d83b11c894b7a29 (commit)
   via  17928cf9f91af72cd5a83480d43cd278aff1f93a (commit)
   via  c39785d4e64587d3a07a8ce8f25046f407107e71 (commit)
  from  ca1ed2904e9235deb8bf2d32629c6a49b61bf7c0 (commit)


- Log -
commit 8ed5f094584203855a2bc8cf35c02267e6f64780
Author: Richard Levitte 
Date:   Thu Mar 15 22:05:00 2018 +0100

VMS C: reduce the dependency paths to be relative

Reviewed-by: Andy Polyakov 
(Merged from https://github.com/openssl/openssl/pull/5631)

commit 433e857214731b45565668931d83b11c894b7a29
Author: Richard Levitte 
Date:   Thu Mar 15 20:38:23 2018 +0100

Visual C: reduce the dependency paths to be relative

Reviewed-by: Andy Polyakov 
(Merged from https://github.com/openssl/openssl/pull/5631)

commit 17928cf9f91af72cd5a83480d43cd278aff1f93a
Author: Richard Levitte 
Date:   Thu Mar 15 20:37:39 2018 +0100

util/add-depends.pl: add the possibility for debug printouts

Reviewed-by: Andy Polyakov 
(Merged from https://github.com/openssl/openssl/pull/5631)

commit c39785d4e64587d3a07a8ce8f25046f407107e71
Author: Richard Levitte 
Date:   Thu Mar 15 18:06:18 2018 +0100

Move all dependency post-processing to util/add-depends.pl

In the end, it's more efficient to only have one perl instance (that
loads configdata.pm) dealing with dependency files than running one
(that still loads configdata.pm) for each such file.

Reviewed-by: Andy Polyakov 
(Merged from https://github.com/openssl/openssl/pull/5631)

---

Summary of changes:
 Configurations/descrip.mms.tmpl  |  14 +-
 Configurations/unix-Makefile.tmpl|  11 +-
 Configurations/windows-makefile.tmpl |   6 +-
 util/add-depends.pl  | 261 +--
 util/postprocess-makedepend.pl   | 160 -
 5 files changed, 259 insertions(+), 193 deletions(-)
 delete mode 100644 util/postprocess-makedepend.pl

diff --git a/Configurations/descrip.mms.tmpl b/Configurations/descrip.mms.tmpl
index cf448aa..f6061f1 100644
--- a/Configurations/descrip.mms.tmpl
+++ b/Configurations/descrip.mms.tmpl
@@ -505,7 +505,7 @@ distclean : clean
 depend : descrip.mms
 descrip.mms : FORCE
@ ! {- output_off() if $disabled{makedepend}; "" -}
-   @ $(PERL) {- sourcefile("util", "add-depends.pl") -}
+   @ $(PERL) {- sourcefile("util", "add-depends.pl") -} "VMS C"
@ ! {- output_on() if $disabled{makedepend}; "" -}
 
 # Install helper targets #
@@ -878,12 +878,9 @@ EOF
   my $incs_on = join("\n\t\@ ", @{$incs_cmds[0]}) || '!';
   my $incs_off = join("\n\t\@ ", @{$incs_cmds[1]}) || '!';
   my $depbuild = $disabled{makedepend} ? ""
-  : " /MMS=(FILE=${objd}${objn}.tmp-D,TARGET=$obj.OBJ)";
-  my $postprocess_makedepend =
-  sourcefile("util", "postprocess-makedepend.pl");
-  my $objdir = dirname($obj);
+  : " /MMS=(FILE=${objd}${objn}.D,TARGET=$obj.OBJ)";
 
-  return <<"EOF"
+  return <<"EOF";
 $obj.OBJ : $deps
 ${before}
 SET DEFAULT $forward
@@ -894,11 +891,6 @@ $obj.OBJ : $deps
 ${after}
 - PURGE $obj.OBJ
 EOF
-  . ($disabled{makedepend} ? "" : <<"EOF"
-\$(PERL) $postprocess_makedepend "VMS C" $objdir < $obj.tmp-D > $obj.d
-- DELETE $obj.tmp-D;*
-EOF
-);
   }
   sub libobj2shlib {
   my %args = @_;
diff --git a/Configurations/unix-Makefile.tmpl 
b/Configurations/unix-Makefile.tmpl
index e9d112b..cb134e7 100644
--- a/Configurations/unix-Makefile.tmpl
+++ b/Configurations/unix-Makefile.tmpl
@@ -12,6 +12,7 @@
  our $shlibextsimple = $target{shared_extension_simple} || ".so";
  our $shlibextimport = $target{shared_import_extension} || "";
  our $dsoext = $target{dso_extension} || ".so";
+ our $makedepprog = $disabled{makedepend} ? undef : $config{makedepprog};
 
  sub windowsdll { $config{target} =~ /^(?:Cygwin|mingw)/ }
 
@@ -419,7 +420,9 @@ distclean: clean
 # concatenate only if that is true.
 depend:
@: {- output_off() if $disabled{makedepend}; "" -}
-   @$(PERL) $(SRCDIR)/util/add-depends.pl
+   @$(PERL) $(SRCDIR)/util/add-depends.pl {-
+defined $makedepprog  && $makedepprog =~ /\/makedepend/
+ ? 'makedepend' : 'gcc' -}
@: {- output_on() if $disabled{makedepend}; "" -}
 
 # Install helper targets #
@@ -970,7 +973,6 @@ EOF
   my $cmd;
   my $cmdflags;
   my $cmdcompile;
-  my $makedepprog =
diff --git a/crypto/rand/drbg_lib.c b/crypto/rand/drbg_lib.c
index 93092c8..360e775 100644
--- a/crypto/rand/drbg_lib.c
+++ b/crypto/rand/drbg_lib.c
@@ -113,6 +113,11 @@ static const char ossl_pers_string[] = "OpenSSL NIST SP 
800-90A DRBG";
 
 static CRYPTO_ONCE rand_drbg_init = CRYPTO_ONCE_STATIC_INIT;
 
+
+
+static int rand_drbg_type = RAND_DRBG_TYPE;
+static unsigned int rand_drbg_flags = RAND_DRBG_FLAGS;
+
 static unsigned int master_reseed_interval = MASTER_RESEED_INTERVAL;
 static unsigned int slave_reseed_interval  = SLAVE_RESEED_INTERVAL;
 
@@ -127,19 +132,26 @@ static RAND_DRBG *rand_drbg_new(int secure,
 RAND_DRBG *parent);
 
 /*
  * Set/initialize |drbg| to be of type |nid|, with optional |flags|.
  *
  * Returns 1 on success, 0 on failure.
  */
-int RAND_DRBG_set(RAND_DRBG *drbg, int nid, unsigned int flags)
+int RAND_DRBG_set(RAND_DRBG *drbg, int type, unsigned int flags)
 {
 int ret = 1;
 
+if (type == 0 && flags == 0) {
+type = rand_drbg_type;
+flags = rand_drbg_flags;
+}
+
 drbg->state = DRBG_UNINITIALISED;
 drbg->flags = flags;
-drbg->nid = nid;
+drbg->type = type;
 
-switch (nid) {
+switch (type) {
 default:
 RANDerr(RAND_F_RAND_DRBG_SET, RAND_R_UNSUPPORTED_DRBG_TYPE);
 return 0;
@@ -159,6 +171,37 @@ int RAND_DRBG_set(RAND_DRBG *drbg, int nid, unsigned int 
flags)
 }
 
 /*
+ * Set/initialize default |type| and |flag| for new drbg instances.
+ *
+ * Returns 1 on success, 0 on failure.
+ */
+int RAND_DRBG_set_defaults(int type, unsigned int flags)
+{
+int ret = 1;
+
+switch (type) {
+default:
+RANDerr(RAND_F_RAND_DRBG_SET_DEFAULTS, RAND_R_UNSUPPORTED_DRBG_TYPE);
+return 0;
+case NID_aes_128_ctr:
+case NID_aes_192_ctr:
+case NID_aes_256_ctr:
+break;
+}
+
+if ((flags & ~RAND_DRBG_USED_FLAGS) != 0) {
+RANDerr(RAND_F_RAND_DRBG_SET_DEFAULTS, RAND_R_UNSUPPORTED_DRBG_FLAGS);
+return 0;
+}
+
+rand_drbg_type  = type;
+rand_drbg_flags = flags;
+
+return ret;
+}
+
+
+/*
  * Allocate memory and initialize a new DRBG. The DRBG is allocated on
  * the secure heap if |secure| is nonzero and the secure 
@@ -127,19 +132,26 @@ static RAND_DRBG *rand_drbg_new(int secure,
 
 /*
- * Set/initialize |drbg| to be of type |nid|, with optional |flags|.
+ * Set/initialize |drbg| to be of type |type|, with optional |flags|.
+ *
+ * If |type| and |flags| are zero, use the defaults
  *
  * Returns 1 on success, 0 on failure.

[openssl-commits] Build failed in Jenkins: master_noec #436

2018-03-16 Thread osslsanity
See 


Changes:

[levitte] Windows makefile: don't use different looking variants of same cmd

[levitte] VMS: add alias macros to avoid 31 character symbol name limit warning

[levitte] Move all dependency post-processing to util/add-depends.pl

[levitte] util/add-depends.pl: add the possibility for debug printouts

[levitte] Visual C: reduce the dependency paths to be relative

[levitte] VMS C: reduce the dependency paths to be relative

[levitte] Configure: Don't fail if there were "make variables" set in env

[levitte] Configure: maintain compability with pre-"make variables" Configure

[levitte] INSTALL: Add a note about backward compatibility and "make variables"
